@@ -26,6 +26,8 @@
 G_BEGIN_DECLS
 GType gcab_compression_get_type (void) G_GNUC_CONST;
 #define GCAB_TYPE_COMPRESSION (gcab_compression_get_type ())
+GType gcab_file_attribute_get_type (void) G_GNUC_CONST;
+#define GCAB_TYPE_FILE_ATTRIBUTE (gcab_file_attribute_get_type ())
 G_END_DECLS
 
 #endif
