@@ -13,7 +13,7 @@
  * a sub-container grouping GCabFiles together, sharing some common
  * settings like the compression method.
  *
- * You can retrieve the files withing a folder with
+ * You can retrieve the files within a folder with
  * gcab_folder_get_files().
  *
  * In order to add a file to a folder for creation, use
@@ -404,7 +404,17 @@ gcab_folder_extract (GCabFolder *self,
 
         u4 usize = file->cfile.usize;
         u4 uoffset = file->cfile.uoffset;
-        do {
+
+        /* let's rewind if need be */
+        if (uoffset < nubytes) {
+            if (!g_seekable_seek (G_SEEKABLE (data), self->cfolder.offsetdata,
+                                  G_SEEK_SET, cancellable, error))
+                goto end;
+            bzero(&cdata, sizeof(cdata));
+            nubytes = 0;
+        }
+
+        while (usize > 0) {
             if ((nubytes + cdata.nubytes) <= uoffset) {
                 nubytes += cdata.nubytes;
                 if (!cdata_read (&cdata, res_data, self->comptype,
@@ -422,7 +432,7 @@ gcab_folder_extract (GCabFolder *self,
                 usize -= count;
                 uoffset += count;
             }
-        } while (usize > 0);
+        }
     }
 
     success = TRUE;
